==> ChatterBot-0.2.6-py2.py3-none-any.whl: chatterbot/conversation/statement.py <==
from .signature import Signature


class Statement(object):

    def __init__(self, text, **kwargs):
        self.text = text
        self.occurrence = kwargs.get("occurrence", 1)

        self.signatures = kwargs.get("signatures", [])

        self.in_response_to = kwargs.get("in_response_to", [])

        self.modified = False

    def __eq__(self, other):
        if not other:
            return False

        if isinstance(other, Statement):
            return self.text == other.text

        return self.text == other

    def __repr__(self):
        return "<Statement text:%s>" % (self.text)

    def __str__(self):
        return self.text

    def add_response(self, statement):
        """
        Add the statement to the list if it does not already exist.
        """
        if not statement.text in self.in_response_to:
            self.in_response_to.append(statement.text)

    def get_occurrence_count(self):
        """
        Return the number of times the statement occurs in the database.
        """
        return self.occurrence

    def update_occurrence_count(self):
        """
        Increment the occurrence count.
        """
        self.occurrence = self.occurrence + 1

    def add_signature(self, signature):
        self.signatures.append(signature)

    def serialize(self):
        """
        Returns a dictionary representation of the current object.
        """
        data = {}

        data["text"] = self.text
        data["occurrence"] = self.occurrence
        data["in_response_to"] = self.in_response_to

        data["signature"] = []

        for signature in self.signatures:
            data["signature"].append(signature.serialize())

        return data

==> ChatterBot-0.3.2-py2.py3-none-any.whl: chatterbot/conversation/statement.py <==
from .signature import Signature


class Statement(object):

    def __init__(self, text, **kwargs):
        self.text = text
        self.in_response_to = kwargs.get("in_response_to", [])

        self.extra_data = {}

        if "in_response_to" in kwargs:
            del(kwargs["in_response_to"])

        self.extra_data.update(kwargs)

    def __str__(self):
        return self.text

    def __repr__(self):
        return "<Statement text:%s>" % (self.text)

    def __eq__(self, other):
        if not other:
            return False

        if isinstance(other, Statement):
            return self.text == other.text

        return self.text == other

    def add_extra_data(self, key, value):
        self.extra_data[key] = value

    def add_response(self, statement):
        """
        Add the statement to the list if it does not already exist.
        """
        updated = False
        for index in range(0, len(self.in_response_to)):
            if statement.text == self.in_response_to[index].text:
                self.in_response_to[index].occurrence += 1
                updated = True

        if not updated:
            self.in_response_to.append(
                Response(statement.text)
            )

    def get_response_count(self, statement):
        """
        Return the number of times the statement occurs in the database.
        """
        for response in self.in_response_to:
            if statement.text == response.text:
                return response.occurrence

        return 0

    def serialize(self):
        """
        Returns a dictionary representation of the current object.
        """
        data = {}

        data["text"] = self.text
        data["in_response_to"] = []
        data.update(self.extra_data)

        for response in self.in_response_to:
            data["in_response_to"].append(response.serialize())

        return data


class Response(object):

    def __init__(self, text, **kwargs):
        self.text = text
        self.occurrence = kwargs.get("occurrence", 1)
        self.signatures = kwargs.get("signatures", [])

    def __str__(self):
        return self.text

    def __repr__(self):
        return "<Response text:%s>" % (self.text)

    def __eq__(self, other):
        if not other:
            return False

        if isinstance(other, Response):
            return self.text == other.text

        return self.text == other

    def add_signature(self, signature):
        self.signatures.append(signature)

    def serialize(self):
        data = {}

        data["text"] = self.text
        data["occurrence"] = self.occurrence
        data["signature"] = []

        for signature in self.signatures:
            data["signature"].append(signature.serialize())

        return data
